@@ -110,7 +110,7 @@ fn get_obf(s:   &str) -> Option<String> {
 
 #[derive(Debug,Clone,PartialEq)]
 pub enum Node {
-    Node(Nodename,Nodeport),
+    Node(Nodename, Nodeport),
     Unknown
 }
 
@@ -129,6 +129,15 @@ impl From<Option<SocketAddr>> for Node {
     }
 }
 
+impl From<Option<IpAddr>> for Node {
+    fn from(saddr:  Option<IpAddr>) -> Self {
+        if let Some(saddr) = saddr {
+            return  Node::Node(saddr.into(),Nodeport::None)
+        }
+        Node::Unknown
+    }
+}
+
 impl fmt::Display for Node {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
